<?php
  /**
   * Plugin Name: Anomate Helper
   * Plugin URI: https://anomate.co
   * Description: Marketing in Minutes, Not Months: Dive Right In!
   * Version: 1.0.1
   * Author: Anomate
   * Author URI: https://anomate.co
   * Text Domain: anomate-helper
   * License: GPL-2.0-or-later
   * License URI: http://www.gnu.org/licenses/gpl-2.0.html
   */

  class AnomateHelper {
    protected static $_instance = null;

    public static function instance() {
      if ( is_null(self::$_instance) ) {
        self::$_instance = new self();
      }

      return self::$_instance;
    }

    public function __construct() {
      add_action( 'plugins_loaded', array($this, 'init') );

      add_filter('query_vars', function($query_vars) {
        $query_vars[] = 'anomate_survey_id';
        $query_vars[] = 'anomate_giveaway_id';
        $query_vars[] = 'anomate_pr_id';

        return $query_vars;
      });
    }

    public static function plugin_activated() {
      $instance = self::instance();

      $instance->register_custom_endpoints();

      flush_rewrite_rules();
    }

    public function register_custom_endpoints() {
      add_rewrite_endpoint('view-email', EP_ROOT);
      add_rewrite_endpoint('unsubscribe', EP_ROOT);

      add_filter('generate_rewrite_rules', function($wp_rewrite) {
        $wp_rewrite->rules = array_merge(array(
          'customer-survey/([^/]+)/?$' => 'index.php?anomate_survey_id=$matches[1]',
          'product-review/([^/]+)/?$' => 'index.php?anomate_pr_id=$matches[1]',
          'raffle-giveaway/([^/]+)/?$' => 'index.php?anomate_giveaway_id=$matches[1]'
        ), $wp_rewrite->rules);
      });
    }

    public function init() {
      if ( class_exists('WooCommerce') ) {
        add_action( 'wp_enqueue_scripts', array($this, 'enqueue_scripts') );
        add_filter( 'body_class', array($this, 'add_body_class') );
      
        require_once 'inc/api.php';
        require_once 'inc/webhooks.php';
        require_once 'inc/campaigns.php';
        require_once 'inc/styles.php';
        require_once 'inc/functions.php';
        require_once 'inc/checkout.php';
        require_once 'inc/modals.php';
        require_once 'inc/tracking.php';
        require_once 'inc/view-email.php';
        require_once 'inc/unsubscribe.php';
      } else {
        add_action( 'admin_notices', array($this, 'no_wc') );
      }
    }

    public function add_body_class($classes) {
      $classes[] = 'anomate';

      return $classes;
    }

    public function enqueue_scripts() {
      global $post;
      
      wp_enqueue_style( 'anomate', plugin_dir_url(__FILE__) . 'dist/style.css', array(), $this->get_version() );
      wp_enqueue_script('anomate', plugin_dir_url(__FILE__) . 'dist/main.js', array('jquery'), $this->get_version(), true);

      wp_localize_script( 'anomate', 'anomate_vars', array(
        'ajax_url' => admin_url('admin-ajax.php'),
        'cart_abandonment_notice_text' => $this->get_cart_abandonment_notice_text(),
        'cart_abandonment_enabled' => get_option('anomate_cart-abandonment'),
        'checkout_marketing_checkbox' => $this->get_checkout_marketing_checkbox_data(),
        'current_modal_placement' => $this->get_current_modal_placement(),
        'product_id' => is_product() ? $post->ID : null,
        'nonce' => wp_create_nonce('anomate'),
        'raffle_giveaway_confirmation_title' => __('Confirm your subscription!', 'anomate-helper'),
        'raffle_giveaway_confirmation_description' => __('Please check your inbox for a confirmation email to finalize your participation. <br>We can\'t wait to see you in the raffle!', 'anomate-helper'),
      ) );
    }

    public function get_current_modal_placement() {
      global $wp_query;

      if ( is_front_page() && !isset($wp_query->query_vars['unsubscribe']) && !isset($wp_query->query_vars['anomate_survey_id']) && !isset($wp_query->query_vars['anomate_pr_id']) && !isset($wp_query->query_vars['anomate_giveaway_id']) ) {
        return 'home-page';
      } else if ( is_singular('post') ) {
        return 'blog-post';
      } else if ( is_product() ) {
        return 'product-page';
      }

      return false;
    }

    public function get_checkout_marketing_checkbox_data() {
      if ( !get_option('anomate_enable_marketing_consent_box') ) {
        return false;
      }

      return array(
        'text' => get_option('anomate_marketing_box'),
        'checked' => get_option('anomate_tick_the_marketing_checkbox_by_default'),
      );
    }

    public function no_wc() {
      echo '<div class="notice notice-error">';

      // Translators: %s is a link to WooCommerce website
      echo '<p>' . sprintf(esc_html__('Anomate Helper requires %s to be installed and active.', 'anomate-helper'), '<a href="https://woocommerce.com/" target="_blank">WooCommerce</a>') . '</p>';
      echo '</div>';
    }
    
    public function get_version() {
      $plugin_data = get_plugin_data(__FILE__);
      
      return $plugin_data['Version'];
    }

    public function get_base_api_url() {
      return 'https://portal.anomate.co/api';
    }

    public function get_base_webhook_url() {
      return $this->get_base_api_url() . '/shop/' . $this->get_token();
    }

    public function get_token() {
      return get_option('anomate_token');
    }

    public function get_plugin_path() {
      return plugin_dir_path(__FILE__);
    }

    public function get_cart_abandonment_notice_text() {
      // Translators: %1$s is an open <a> tag
      // Translators: %2$s is a closed </a> tag
      return sprintf(__('We save your email and cart so we can send you reminders - %1$sdon\'t email me%2$s.', 'anomate-helper'), '<a href="#" class="anomate-email-usage-notice__link">', '</a>');
    }

    public function redirect404() {
      global $wp_query;

      $wp_query->set_404();

      status_header(404);
      get_template_part(404);
      
      exit; 
    }
  }

  register_activation_hook( __FILE__, array('AnomateHelper', 'plugin_activated') );

  function AnomateHelper() {
    return AnomateHelper::instance();
  }

  AnomateHelper();
?>